# Mathematik

[TOC]

##1. Grundlagen

###1.1 Summen und Produktschreibweise

####1.1.1 Definition
Eine Summe von reellen (oder komplexen)  Zahlen $a_{0},a_{1},...,a_{n}$ schreibt man Abkürzend: 
$$\sum_{k=0}^{n}[a_{k}] = a_{0} + a_{1}+a_2+a_3+...+a_n$$
gelesen : "Summe über alle $a_k$ für alle $k=0$ bis n"
```
var a = array(); 
var sum = 0;
for(int i = 0; i<=n; i++) sum+=a[i];
```

####1.1.2 Beispiel 
1. Berechnen Sie $$\sum_{k=1}^4 k^2 = 1^2+2^2+3^2+4^2 = 30$$
2. Berechnen Sie $$\sum_{m=1}^3 (-1)^{m+1}*\frac{1}{m} = (-1)^{2}*\frac{1}{1} + (-1)^{3}*\frac{1}{2} + (-1)^{4}*\frac{1}{3} = \frac{5}{6}  $$

####1.1.3 Satz (Rechenregel für Summen)
Für $n \epsilon\mathbb{N}$, reelle oder komplexe Zahlen $a_0, ..., a_n, b_0, ..., b_n, c$ gilt:
$$\sum_{k=0}^n(a_k+b_k) = \sum_{k=0}^na_k + \sum_{k=0}^nb_k$$
$$\sum_{k=0}^n(c*a_k) = c * \sum_{k=0}^na_k$$
####1.1.4 Satz (Vertauschung von Summen)
Für $n,m\epsilon\mathbb{N}$, reellen oder komplexen Zahlen $a_0, ..., a_n$ gilt abkürzend
$$\sum_{j=0}^m\sum^n_{k=0}a_{jk}=\sum_{k=0}^n\sum^m_{j=0}a_{jk}$$

<hr>
####1.1.5 Definition
Auch für Produkte von reellen oder komplexen Zahlen $a_0, .. 1_n$ gilt abkürzend:

$$\prod_{k=0}^na_k = a_0 * a_1 * a_2 * .. * a_n$$ 
gelesen: "Produkte über alle $a_k$ von $k=0$ bis $n$"

**Bemerkung**
Das Produkt der ersten $n$ natürlichen Zahl wird als Fakultät bezeichnet. $$n! = 1*2*3*...*n = \prod_{k=1}^nk$$
<hr>

##1.2 Mathematische Beweismethoden

###$\mathrm{I.}$ Der Direkte Beweis
Das Ziel ist aus einer Aussage A (Vorraussetzung) eine Aussage B zu Beweisen. Dabei beginnt man mit der Aussage A und führt diese durch erlaubte mathematische Operationen in die Aussage B über, also $A\rightarrow B$. 

####1.2.1 Beispiel
Zeigen Sie mit Hilfe des direkten Beweises folgende Behauptung:
<i>
Für eine Zahl $x\ne 1$ und eine natürliche Zahl $n\epsilon\mathbb{N}$ sei 
$$S_n(x)=1+x+x^2+...+x^n=\sum^n_{k=0}x^k$$
Dann gilt
$$S_n(x)=\frac{1-x^{n+1}}{1-x}$$</i>
**Beweis**
**Es sei $x\epsilon\mathbb{N}$ und $x\ne 1, n\epsilon\mathbb{N}$.**
$$S_n(x) = 1+x+x^2+...+x^n | *x$$
$$x*S_n(x) = x+x^2+x^3+...+x^{n+1}$$
Subtrahiert man beide Zahlen, so erhält man 
$$S_n(x)-x*S_n(x)=1-x^{n+1}$$
$$S_n(x)*(1-x)=1-x^{n+1}|:(1-x)\ne 0$$
$$S_n(x)=\frac{1-x^{n+1}}{1-x}$$
###$\mathrm{II.}$ Der Indirekte Beweis (Widerspruchsbeweis)
Bei einem indirekten Beweis zeigt man, dass ein Widerspruch entstünde, wenn die zu beweisende Behauptung falsch wäre. Dazu nimmt man an, dass die Behauptung falsch ist, und wendet die gleiche Methode wie beim direkten Beweis an. Wenn daraus ein Wiederspruch ensteht, dann kann die Behauptung nicht falsch sein, defacto muss sie richtig sein. <code>Satz vom ausgeschlossenen Drittel</code>*$A\land\neg B\rightarrow \downarrow$

####1.2.2 Beispiel
Zeigen Sie mit Hilfe eines indirekten Beweises folgende Behauptung
<i>Für alle $n\epsilon\mathbb{N}$ gilt: ist $n$ ungerade $\rightarrow$ **$n^2$ ist ungerade** </i>
**Beweis**
**Es sei $n\epsilon\mathbb{N}$.** Wir nehmen an, dass $n$ ungerade und $n^2$ <u>*gerade*</u> ist, wenn $n$ ungerade und $n=2k+1$ ist mit $k\epsilon\mathbb{N}$. $n^2=(2K+1)^2=4k^2+4k+1 = 4(k^2+k)+1$ ist somit aber ungerade.
Nach Annahme ist aber $n^2$ gerade. Das ist ein Widerspruch. <u>*Die Annahme* </u>ist also falsch. Es gilt somit die Verneinung und das ist die Behauptung.

####1.2.3 Beispiel
Zeigen Sie mit Holfe des indirekten Beweises folgende Behauptung: "Es gibt unendlich viele Primzahlen"
**Beweis**
Wir negieren die Behauptung und erhalten die Aussage: "Es gibt endlich viele Primzahlen" $P_1,P_2,P_n$, die wir nach ihrer größe sortieren $P_1<P_2<P_n$. Wir bilden nun die Zahl $$p=(\prod_{k=0}^nP_k)+1$$
Dann gilt:
$p>P_n$, Keiner der Zahlen $_1, P_2, P_n$ ist Teiler von $P$, denn bei der Division durch eine Primzahl erhalten wir stets den Rest 1.

Ist $p$ eine Primzahl, dann erhalten wir einen Widerspruch zur Annahme, dass $P_n$ die größte Primzahl ist.
Ist $p$ keine Primzahl, dann muss eine Zahl $z\ne1$ geben, die $p$ teilt. In obiger Aussage haben wir aber festgestellt, dass keine der Zahlen $P_1, ..., P_n$ Teiler von $p$ ist, also muss $z>P_n$ sein. Wieder erhalten wir einen Widerspruch zur Annahme, dass $P_n$ die größte Primzahl ist.
$\rightarrow$ Es gibt keine größte Primzahl und somit unendlich viele Primzahlen.
<code>Satz von Euklid, 365-300 v.Chr.</code>

###Die Kontraposition
Anstelle von $A\rightarrow B$ wird die logisch äquivalente Aussage $\neg B\rightarrow\neg A$ direkt bewiesen.

####1.2.4 Beispiel
Zeigen Sie mit Hilfe der Kontraposition folgende Behauptung:
Für alle $n\epsilon\mathbb{N}$ gilt: Ist $n^2$ ungerade $\rightarrow n$ ungerade

**Beweis**
Es sei  $n\epsilon\mathbb{N}$. Die logisch Äquivalente Aussage lautet:
$n$ ist gerade $\rightarrow n^2$ gerade
Wenn $n$ gerade ist: $n=2k$ mit  $k\epsilon\mathbb{N_0}$
$n^2=(2k)^2 = 4k^2$ ist gerade.
Also ist die logisch äquivalente Behauptung bewiesen.

###Die vollständige Induktion
####1.2.5 Satz (Induktionsprinzip oder vollständige Induktion)
Es sei $A_{(n)}$ eine Aussageform, welche von natürlichen Zahlen  $n\epsilon\mathbb{N}$ abhängig ist, sodass gilt:
* $A_{(n)}$ ist richtig für eine Zahl  $n_0\epsilon\mathbb{N}$ (Induktionsanfang)
* Aus der Richtigkeit von $A_{(n)}$ für eine Zahl $n\ge n_0$ folgt stets eine Richtigkeit von $A_{(n+1)}$
  Dann gilt $A_{(n)}$ ist richtig für  $n\epsilon\mathbb{N}$

####1.2.6 Beispiel
 Für jede natürliche Zahl  $n\epsilon\mathbb{N}$ gilt: 
 $$1+2+...+n=\sum_{K=0}^nk=\frac{n(n+1)}{2}$$
 **Beweis**
 Aussage $A_{(n)}$ lautet:
 $$\sum_{k=0}^nk=\frac{n(n+1)}{2}$$
 1. **Induktionsanfang**
$$A_{(1)}: \sum_{k=0}^nk=1=\frac{1(1+1)}{2}$$
$\rightarrow A_{(1)}$ ist richtig 
 2. **Induktionsschritt**
 Wir nehmen an, dass $A_{(1)}$ richtig ist:
  $$\sum_{k=0}^nk=\frac{n(n+1)}{2}$$
  Jetzt betrachten wir $A_{(n+1)}$
  $$\sum_{k=0}^{n+1}k=\sum_{k=0}^nk+(n+1)=^{I.A} \frac{n(n+1)}{2}+(n+1)=\frac{n(n+1)+2(n+2)}{2}=\frac{(n+1)(n+2)}{2}$$
  $\rightarrow$ gilt $A_{(n)}$ für alle  $n\epsilon\mathbb{N}$ 
  
####1.2.7 Beispiel
Es soll eine Formel gefunden werden, die die Summe der ersten n ungeraden Zahlen vereinfacht und diese Formel soll bewiesen werden.
$$\sum_{k=1}^{n}2k-1=n^2$$
$n=1:1$
$n=2:1+3=4$
$n=3:1+3+5=9$

**Beweis mit vollständiger Induktion**
1. Schritt (Induktionsanfang)
$$\sum_{k=1}^{1}(2k-1)=1=1^2$$
2. Schritt (Induktionsschritt)
Wir nehmen an, dass die Aussage für n gelte: 
$$\sum_{k=1}^{n}(2k-1)=n^2$$
Dann gilt für $A_{(n+1)}$
$$\sum_{k=1}^{n+1}2k-1=\sum_{k=1}^{n}(2k-1)*2(n+1)-1 =^{I.A.} = n^2+2(n+1)-1=n^2+2n+1=(n+1)^2 \rightarrow A(n) \ gilt \ \forall n\in\mathbb{N}$$

####1.2.8 Beispiel (Bernoulli'sche Ungleichung)
Für alle reellen Zahlen $x\in\mathbb{R}$ mit $x\ge-1$ und für alle natürlichen Zahlen $n\in\mathbb{N}$ gilt:
$$(1+x)^n=1\ne n*x$$
Es sei $x\in\mathbb{R}$ mit $x\ge-1$ somit ist $1+x\ge0$

**Beweis**

1. Induktionsanfang
	$(1+x)^1=(1+x)\ge1+1*x$
2. Induktionsschritt
	Wir nehmen an, es gelte $1(x+n)^n\ge1+n*x$
	$(1+x)^{n+1}=(1+x)*(1+x)^n\ge(1+x)(1+n*x)$
	($\rightarrow$ausmultipliziert) $= 1+x+n+x+(n*x^2)_{\ge0} \ge 1+x+n*x = 1+(n+1) * x$
	Somit ist die Aussage $n\in\mathbb{N}$ bewiesen.
####1.2.9 Beispiel
Zeigen Sie, dass für alle $n\in\mathbb{N}$ der Ausdruck $9^n-1$ durch $8$ teilbar ist.

**Beweis**

1. Induktionsanfang
$n=1\ |\ 9^n-1\rightarrow 9^1-1=8$: ist durch $8$ teilbar.
2. Induktionsschritt
   Wir nehmen an, dass $9^n-1$ durch $8$ teilbar ist.
   $9^{n+1}-1=9*9^n-1=8*9^n+(9^n-1)_{teilbar}$
   oder: $9(9^n-1)_{teilbar}+8$

####1.2.10 Beispiel
Zeigen sie, dass $\forall n\in\mathbb{N}$ gelte:
$$\prod_{k=1}^n(1+\frac{1}{k})=n+1$$

1. Induktionsanfang
  $n=1$
  $$\prod_{k=1}^n(1+k\frac{1}{k})=1+1\rightarrow(1+\frac{1}{1})=1+1$$
2. Induktionsschritt
  Wir nehmen an, es gelte $$\prod_{k=1}^n(1+\frac{1}{k})=n+1$$ $n=n+1$
  $$\prod_{k=1}^{n+1}(1+\frac{1}{k})=n+1$$
  $$\prod_{k=1}^n(1+\frac{1}{k})*(1+\frac{1}{n+1})=^{I.A.}(n+1)*(1+\frac{1}{n+1})$$
  $$=^{(ausmultipliziert)} n+1+1=n+2$$$\rightarrow$ Somit ist die Aussage $\forall n\in\mathbb{N}$ bewiesen

####1.2.11 Beispiel (Das Lemma von der gemischten Sauna)
>Alle Menschen in einer gemischten Sauna haben das selbe Geschlecht

**Beweis**

1. Induktionsanfang
 einer in der Sauna hat ein Geschlecht
2. Induktionsschritt
 Wir nehmen an, $n$ haben das selbe Geschlecht
 In einer Sauna befinden sich $n$ Leute, mit jeder Runde verlässt einer die Sauna und dann wird überprüft ob alle das selbe Geschlecht haben, danach darf die Person die Sauna wieder betreten.
 $\rightarrow$ Der Induktionsanfang ist falsch, da nicht ein Mensch das selbe Geschlecht haben darf, in diesem Beispiel hätte die Basis $n=2$ sein müssen und damit wäre dann die Aussage falsch gewesen.
###1.3 Binomischer Lehrsatz
####1.3.1 Satz (Binomischer Lehrsatz)
Für alle reellen (oder komplexen) Zahlen $x$ und $y$ und für alle natürlichen Zahlen $\forall n\in\mathbb{N}_0$ gilt die Gleichung:
$$(x+y)^n=\sum_{k=0}^n{n\choose k}x^{n-k}y^k$$
Die Koeffizienten dieses Polynomausdrucks sind Binomialkoeffizienten, die wie folgt definiert sind:
$${n \choose k} = \frac{n!}{k!*(n-k)!}$$

---

> **Notiz:**
> **Polynom** 
> $a_{koeffizient}x^5+bx^4+cx^3+dx^2+ex+f = 0$
> $$p(x) = \sum^n_{k=0}x^k*a_k$$
> **Pascal'sches Dreieck**
> $(x+y)^0 = 1$
> $(x+y)^1 = x+y$
> $(x+y)^2 = x^2+2xy+y^2$
> \begin{array}{ccccccccc}
    &   &   &   & 1 &   &   &   &   \\
    &   &   & 1 &   & 1 &   &   &   \\
    &   & 1 &   & 2 &   & 1 &   &   \\
    & 1 &   & 3 &   & 3 &   & 1 &   \\
  1 &   & 4 &   & 6 &   & 4 &   & 1 \\
\end{array}

---

**Bemerkung**
Für die Binonmialkoeffizienten gilt folgender Zusammenhang
$${n \choose k} + {n \choose k-1} = \frac{n}{k!*(n-k)!}+\frac{n!}{(k-1)!*(n-k-1)!} = \frac{n!*(n-k+1)+n!*k}{k!*(n-k+1)!}$$
$$=\frac{n!(n-k+1+k)}{k!(n-k+1)}=\frac{n!(n+1)}{k!(n+1-k)!}=\frac{n+1}{k!((n+1)-k)!}={n+1 \choose k}$$

####1.3.2 Beweis des Lehrsatzes
Es seien $x,y$ reelle oder komplexe Zahlen.

1. Induktionsanfang
$$n=1$$
$$(x+y)^1=(x+y)$$
$$\sum^1_{k=0}{1 \choose k}x^{1-k}y^k={1 \choose 0}x^1y^0+{1\choose1}x^0y^1$$
$$= 1*x+1*y = x+y$$
2. Induktionsschritt
 Wir nehmen an, es gelte
$$(x+y)^n=\sum^n_{k=0}   {n \choose k}x^{n-k}y^k$$
$$=x\sum_{k=0}^n{n \choose k}x^{n-k}y^k+y\sum_{k=0}^n{n\choose k}x^{n-k}y^k$$
$$=\sum^n_{k=0}{n\choose k}x^{n-k+1}y^k+\sum^n_{k=0}{n \choose k}x^{n-k}y^{k+1}$$
$$=x^{n+1}+\sum_{k=1}^n{n\choose k}x^{n-k+1}y^k+\sum_{k=0}^{n-1}x^{n-k}y^{k+1}+y^{n+1}$$
$$=x^{n+1}+\sum_{k=1}^n{n\choose k}x^{n-k+1}y^k+\sum_{k=1}^n{n \choose k-1}x^{n-k+1}y^k+y^{n+1}$$
$$=x^{n+1}+\sum^{n}_{k=1}[{n \choose k} + {n \choose k-1}]x^{n-k+1}y^k+y^{n+1}$$
$$=x^{n+1}+\sum_{k=1}^n{n+1 \choose k} x^{n+1-k}y^k+y^{n+1}$$
$$=\sum^{n+1}_{k=0}{n+1\choose k}x^{n+1-k}*y^k\checkmark$$ 
 

##2. Mengenlehre

###2.1 Mengenbegriff

####2.1.1 Definition

Eine Menge ist eine Zusammenfassung von wohl unterschiedenen Objekten unserer Anschauung oder unseres Denkens zu einem Ganzen

####2.1.2 Beispiel
 Die Zahl $1,2,3$ bilden eine endliche Menge $A = \{1,2,3\}$, die Menge der ganzen Zahlen $\mathbb{Z}$ eine unendliche Menge

####2.1.3 Definition

Die Objekte $x$, die in einer Menge $A$ zusammengefasst werden, bezeichnet man als Elemente der Menge $A$. Man sagt auch, dass $x$ in $A$ enthalten ist und schreibt $x\in A$. Ist $x$ in $A$ nicht enthalten, so schreibt man $x\notin A$.
Die Menge $\empty$, die kein Element besitzt, heißt leere Menge.

####2.1.4 Definition

Eine Menge $A$ heißt Teilmenge einer Menge $B$, in Zeichen $A\supseteq$B, wenn jedes Element $x$ aus $A$  auch in $B$ enthalten ist.

####2.1.5 Definition

Zwei Mengen $A,B$ sind gleich, iZ $A=B$, wenn sie dieselben Elemente enthalten.

####2.1.6 Satz 
 
Zwei Mengen $A,B$ sind genau dann gleich, wenn sowohl $A$ Teilmenge von $B$ als auch $B$ Teilmenge von $A$ ist, dh.:
$$A=B \leftarrow\rightarrow A\supseteq B \ und \ B\supseteq A$$

####2.2.7 Beispiel

- gerade Zahlen $A=\{x\in\mathbb{N}|x=2k\ mit\ k\in\mathbb{N}$

###2.2 Operationen und Mengen

####2.2.1 Definition

Die Vereinigung $A\cup B$ zweier Mengen $A,B$ enthält genau jene Elemente $x$, die in $A$ oder in $B$ enthalten sind, dh
$$A\cup B := \{x|x\in A \lor x\in B\}$$

####2.2.2 Definition
Der Durchschnitt $A\land B$ zweier Mengen $A,B$ enthält genau jene Elemente $x$, die sowohl $A$ als auch in $B$ enthalten sind, dh.
$$A\cap B := \{x | x \in A \land x\in B\}$$

**Bemerkung**
Es sei $\mathrm{I}$ eine Menge (Indexmenge) und für alle $i\in\mathrm{I}$ sei $A_i$ eine eine Menge, dann ist:
$$\bigcup_{k\in\mathrm{I}} A_k = \bigcup(A_i|i\in\mathrm{I}):= \{x|\exists i\in\mathrm{I} \ mit\ x\in A_i$$
 
die Vereinigung aller $A_i$ mit $i\in\mathrm{I}$

####2.2.3 Definition

Die Differenz zweier Mengen
$$A \setminus B := \{x|x\in A \land x\notin B\}$$
ist die Menge der Elemente von A ohne die Elemente von B. Ist B eine Teilmenge von A, so bezeichnet man $A\setminus B$ auch als das Komplement von B in A und schreibt dafür $\overline B$ 

####2.2.4 Beispiel

$A = \{2,3,4\},\ B = \{3,4,7\}$
$A\cup B = \{2,3,4,7\},\ A\cap B = \{3,4\}$
$A \setminus B = \{2\}$
$\{1,2,3\} \cup \{3,4\} = \{1,2,3,4\}$
$\{1,2,3\} \cap \mathbb{N} = \{1,2,3\}$
$ \mathbb{N} \setminus 1 = \{x\in \mathbb{N} | x \ge 2\}$
####2.2.5 Definition
Man bezeichnet $(a,b)$ als geordnetes Paar (auch Tupel). Zwei geordnete Paare $(a,b)$ und $(a', b') $ sind genau dann gleich, wenn $a=a'$ und $b=b'$ ist.
####2.2.6 Definition
Die Menge aller geordneten Paare zweier Mengen  und B wird karthesisches Produkt von A un B genannt und als $A\times B$ geschrieben:
$A\times B = \{(a,b)|a\in A\land b\in B\} gelesen "A kreuz B"
####2.2.7
$(1,2)\ne(2,1)$
$\{1,2\}\times\{3,4\}=\{(1,3),(1,4),(2,3),(2,4)\}$

>**Bemerkung**
>Man schreibt auch für das n-fache Produkt einer Menge A
>$A\times A\times A\times A = A^n$

###2.3 Relationen
Nehmen wir die Menge der Städte {Wien, Berlin, Zürich} und die Menge aller Staaten Europas. Die Bezeichnung "die Stadt a liegt im Land b" ist dann eine Beziehung zwischen den Städte und jener der Länder.
Sie kann durch Paare angegeben werden, wie Wien - Österreich, Berlin - Deutschland, Schweiz - Zürich
####2.3.1 Definition
Eine Relation R zwischen den Mengen A und B ist eine Teilmenge des kartesischen Produktes $A\times B$, also $R \subseteq A\times B$. Für $(a,b)\in R$ sagt man: "a steht in Relation zu b".
Oft schreibt man auch aRb statt $(a,b)\in R$
####2.3.2 Beispiel
$A=\{2,3,4,5,6\} = B$ Geben Sie Paare der Relation "a ist ungleich b und a teilt b" an.
$R = \{(2,4),(2,6),(3,6)\}$ 
####2.3.3 Definition
Es sei $R\subseteq A\times B$ eine Relation.
Dann heißt die Relation $$R^{-1} = \{(b,a),(a,b)\in R)\}\subseteq B\times A$$ die zu R inverse Relation (oder die Umkehrrelation)
####2.3.4 Beispiel
Selbe Mengen wie 2.3.2, dann ist
$R^{-1} = \{(4,2),(6,2),(6,3)\}$ die Umkehrrelation
####2.3.5 Definition
Aus zwei Relationen $R\subseteq A\times B$ und $S\subseteq B\times C$ kann man eine neue Relation, die Verkettung (oder Verknüpfung oder das Produkt) bilden.
$$R\circ S = \{(a,c)\exists b\in B: (a,b) \in R \land (b,c) \in S\} \supseteq A\times C$$
####2.3.6 Beispiel
R ist die Relation "ist die Mutter von" und S ist die Relation "ist verheiratet mit" in der Menge aller Menschen.
Dann ist die Verkettung der Relationen $R\circ S$ die Relation "ist Schwiegermutter von".
####2.3.7 Beispiel
Bilden Sie die Verknüpfung aller Relationen 
$R = \{(1,a),(2,b),(2,c)\}$ und $R = \{(a,x),(a,y),(b,z)\}$
$R\circ S = \{(1,x),1,y),(2,z)\}$

---

Bisher haben wir Relationen zwischen zwei Mengen $A$ und $B$ betrachtet. Nun betrachten wir den Spezialfall $R\le A\times A$. Man spricht in diesem Fall von einer Relation auf $A$.

####2.3.8 Definition
Eine Relation R in a heißt.
- Reflexiv, wenn $(a,a)\in R\forall a\in A$
- Symmetrisch, wenn für alle $a,b\in A$ gilt: $(a,b)\in R\Rightarrow (b,a)\in R$
- Antisymmetrisch, wenn für alle $a,b\in A$ gilt: $(a,b)\in R\land (b,a)\in R \Rightarrow a=b$
- Asymmetrisch, wenn für alle $a,b\in A$ gilt: $(a,b)\in R\Rightarrow (b,a)\notin R$
- Transitiv, wenn für alle $a,b,c\in A$ gilt: $(a,b)\in R\land (b,c)\in R \Rightarrow (a,c)\in R$

####2.3.9 Beispiel

|     # | reflexiv|symmetrisch|Antisymmetrisch|Asymmetrisch|transitiv|
| :------- | :---: | :---: | :---: | :---: | :---: |
| ist gleichalt wie| $\checkmark$ |$\checkmark$ |$\times$ | $\times$ |$\checkmark$ |
| ist verwandt mit| $\checkmark$ |$\checkmark$ |  $\times$    | $\times$    |$\times$ |
| ist Mutter von| $\times$ |$\times$ |  $\checkmark$   | $\checkmark$    |$\times$ |
| ist älter als| $\times$ |$\times$ |  $\checkmark$    | $\checkmark$    |$\checkmark$ |

####Äquivalenzrelationen
####2.3.10 Definition
Eine Relation $R$ auf eine Menge $A$ heißt Äquivalenzrelation, wenn sie reflexiv, symmetrisch und transitiv ist. Für $(a,b)\in R$ sagt man auch: "$a$ ist äquivalent zu $b$".

####2.3.12 Beispiel
#####(a)
Ist $R=\{(1,1),(1,-1),(-1,1),(-1,-1),(2,2),(2,-2),(-2,2),(-2,-2)\}$ eine Äquivalenzrelation auf $A=\{-2,-1,1,2\}$?
reflexiv $(-1,-1)$ u. $(2,2)$ u. $(-2,-2)$ u. $(1,1)$ 
symmetrisch $(1,-1)$ u. $(-1,1)$ o. $(2,-2)$ u. $(-2,2)$ 
transitiv $(-2,2)$ u. $(2,2)$ u. $(2,-2)$ o. $(-1,1)$ u. $(1,1)$ u. $(1,-1)$
$\Rightarrow$ Äquivalenzreaktion

#####(b)
$(a,b)\in R$ ist die Relation "$a$ ist in der gleichen Gehaltsstufe wie $b$"
$\rightarrow$ reflexiv, symmetrisch, transitiv $\Rightarrow$ Äquivalenzrelation
#####(c)
$(a,b)\in R$ ist die Relation "$a$ arbeitet im selben Projekt wie $b$"
$\rightarrow$ reflexiv, symmetrisch, nicht transitiv $\not\Rightarrow$ <s>Äquivalenzrelation</s>

####Ordnungsrelation
####2.3.13 Definition

Eine Relation $R$ auf eine Menge $A$ heißt Ordnungsrelation, partielle Ordnung oder Halbordnung, wenn sie reflexiv, antisymmetrisch und transitiv ist.

####2.3.14 Beispiel
Eine Relation $\le$ in $\mathbb{N}$ ist eine Ordnungsrelation.
- reflexiv, da $a\le a\forall a\in\mathbb{N}$
- antisymmetrisch, denn für $a, b\in\mathbb N$ mit $a\le b$ und $b\le a\Rightarrow a=b$
- transitiv, denn für $a\le b$ und $b\le c$ folgt $a\le c$

####2.3.15 Definition
ist $M$ eine halbgeorndete Menge und $T$ eine Teilmenge von $M$, so gilt:
- Ein Element $b\in M$ heißt *obere Schranke* von $T$, wenn $\forall x\in T$ gilt: $b\ge x$
- Ein Element $b\in M$ heißt *untere Schranke* von $T$, wenn $\forall x\in T$ gilt: $b\le x$
- Existiert eine obere Schranke, dann ist $T$ nach oben beschränkt
- Existiert eine untere Schranke, dann ist $T$ nach unten beschränkt
- Existiert eine Schranke, dann ist $T$ beschränkt
- Ein Element $b\in M$ heißt *Supremum* von$T$, wenn $b$ die kleinste obere Schranke von $T$ ist, dh wenn $b$ die obere Schranke ist und kleiner als alle anderen oberen Schranken: $b=\sup T$
-  Ein Element $b\in M$ heißt *Infimum* von$T$, wenn $b$ die größte untere Schranke von $T$ ist, dh wenn $b$ die untere Schranke ist und größer als alle anderen unteren Schranken:  $b=\inf T$

**Bemerkung**
Ist $T$ nach oben unbeschränkt, dann schreibt man auch  $\sup T = +\infty\ +\notin\mathbb R$ und ist auch kein Supremum von $T$ in dem Sinn.
Nach unten unbeschränkt: $\inf T = -\infty$
$T=\{x\in\mathbb R | 0 \lt x\lt 1\} \inf T = 0, \min T $ existiert nicht
$T=\{x\in\mathbb R | 0 \le x\le 1\} \sup T = 1, \max T $ existiert nicht
$\sup{\{x\in\mathbb Q |x^2\lt 2\}}=  \sqrt{2}\in \setminus \mathbb Q$
$\sup{\{(-1)^n-\frac{1}{n}| n\in\mathbb N\}} = 1\  \max$ existiert nicht

###2.4 Abbildung
####2.4.1 Definition

Eine Abbildung oder Funktion $f$ von einer Menge $M$ ist eine Vorschrift, die jedem Element $x\in D$ genau ein Element $f(x)\in M$ zuordnet. Man schreibt dafür: $f:\rightarrow M; x\mapsto f(x)$
und sagt "$x$ wird auf $f(x)$ abgebildet" bzw. "$f(x)$ ist das Bild (oder der Funktionswert) von $x$" und die Menge $D$ ist der Definitionsbereich. Die Menge $f(D) = \{f(x)|x\in D\}$ heißt Bildmenge und die Menge $M$ ist der Wertebereich.

####2.4.2 Beispiel
#####(a)
Die Abbildung $F:\mathbb N \rightarrow\mathbb N$ mit $f(n)=n^2$
Definitionsbereich $D=\mathbb N$
Wertebereich $M=\mathbb N$
Bildmenge $f(D) = \{f(x)|x\in\mathbb N\} = \{1,4,9,\dots\}$
#####(b)
Die Abbildung $g: \mathbb Z\rightarrow\mathbb Z$ mit $g(z)=z^2$
Definitionsbereich $\mathbb Z$
Wertebereich $\mathbb Z$
Bildmenge $f(D)=\{z^2|z\in\mathbb Z\}=\{0,1,4,9,\dots\}$
#####(c)
Die Abbildung $f:\mathbb R\times\mathbb R\ f(x_1,x_2)=x_1+x_2$
$f(D)=\mathbb R$
####2.4.3 Definition
Es sei $f:D\rightarrow M$ eine Abbildung.
- $f$ heißt injektiv, wenn verschiedene Elemente von $D$ auf verschiedene Elemente von $M$ abgebildet werden, kurz $$x_1\ne x_2\Rightarrow f(x_1)\ne f(x_2)\forall x_1,x_2\in D$$  
Anders gesagt: $f$ ist injektiv, wenn $f(x_1)=f(x_2)\Rightarrow x_1=x_2\forall x_1,x_2\in D$
- surjektiv, wenn jedes Element von $M$ das Bild eines Elements au $D$ ist: $f(D)=M$
- bijektiv: surjektiv und injektiv

####2.4.4 Beispiel
Welche der folgenden Abbildung ist injektiv, surjektiv, und/oder bijektiv
a) $f:\mathbb Z\rightarrow\mathbb N, n\mapsto n^2$
$f$ ist nicht injektiv, da gilt $f(x)=f(-x) und x\ne-x$
$f$ ist nicht surjektiv, da $f(D)\neM\ge$ z.B. für 3
b) $g:\mathbb N\rightarrow\mathbb N, n\mapsto n^2$
$g$ ist injektiv, da $g(x)=g(y)$ also $x^2=y^2,x=y$
$g$ ist nicht surjektiv, da $g(D)\ne M$
###2.5 Mächtigkeit
####2.5.1 Definition
Zwei Mengen $x,y$ heißen von gleicher Mächtigkeit, wenn es eine bijektive Abbildung
$f:D\mapsto M$ gibt, mit $D=X$ und $M=Y$
####2.5.2 Beispiel
Die Mengen $x=\mathbb N = \{0,1,2,3,\dots\}$ und $Y=\{0,2,4,6,\dots\}$ sind von gleicher Mächtigkeit. Wir wählen etwa $f: x\rightarrow y$ mit $x\mapsto2x$
####2.5.3 Definition
Eine Menge $M$ heißt endlich, wenn sie leer ist oder es ein $n\in\mathbb N$ und eine bijektive Abbildung von $\{1,2,\dots,n\}$ auf $M$ gibt. Wir sagen dann, $M$ hat $n$ Elemente und schreiben dafür $|M|=n$. Eine nicht endliche Menge $M$ heißt unendlich; $M=\infty$. Eine Menge $M$ heißt abzählbar unendlich oder kurz abzählbar, wenn sie von der gleichen Mächtigkeit wie die Menge $\mathbb N$ der Natürlichen Zahlen ist, andernfalls ist sie überabzählbar.

**Bemerkung**
Eine Menge ist abzählbar, wenn ihre Elemente "durchnummeriet werden können, dh wenn jedem Element der Menge genau eine Zahl als Platzhalter gegeben werden kann.

####2.5.4 Beispiel

| $\mathbb N$ | 1 | 2 | 3 | 4 | 5 | $\dots$|
|:----:|:----:|:----:|:----:|:----:|:----:|:----:|
|Platznr.|1|2|3|4|5|$\dots$|

| $\mathbb N_0$ | 0 | 1 | 2 | 3 | 4 | $\dots$|
|:----:|:----:|:----:|:----:|:----:|:----:|:----:|
|Platznr.|1|2|3|4|5|$\dots$|

$\Rightarrow\ \mathbb N$ und $\mathbb N_0$ sind gleichmächtig!

| $\mathbb Z$ | 0 | -1 | 1 | -2 | 2 | $\dots$|
|:----:|:----:|:----:|:----:|:----:|:----:|:----:|
|Platznr.|1|2|3|4|5|$\dots$| 

$\mathbb Q$

```flow
st=>start: 1/1
e=>end: ...
op1=>operation: 2/1
op2=>operation: 1/2
op3=>operation: 1/3
op4=>operation: 2/2
op5=>operation: 2/3
op6=>operation: 3/3
op7=>operation: 3/2
op8=>operation: ...

st->op1->op2->op3->op4->op5->e
```

Die Rationalen Zahlen $\mathbb Q$ lassen sich nummerieren
- Georg Cantor

Die Menge $\mathbb R$ ist überabzählbar.
Man beschränkt sich auf das Intervall $[0,1]$ und man nimmt an, dass dieses Intervall abzählbar wäre:
1. Zahl: $0,5148309\dots\rightarrow$  5 wird zu 6
2. Zahl: $0,4354789\dots\rightarrow$  3 wird zu 5
3. Zahl: $0,14798\dots\rightarrow$ 7 wird zu 6
Es wird nun eine Zahl konstruiert, die an der n-ten Nachkommastelle von der n-ten Zahl verschieden ist.
neue Zahl: $0,656\dots$
Diese Zahl unterscheidet sich von allen Zahlen in der Liste. Das heißt, dass die Liste nicht alle Zahlen des Intervalls umfassen kann
$\Rightarrow \mathbb R$ ist überabzählbar

###2.6 Gruppen und Körper
####2.6.1 Definition
Es sei $G$ eine Menge mit einer Verknüpfung, die je zwei Elementen $a,b\in G$ ein Element $a\circ b\in G$ zuordnet.
Dann wird $(G, \circ)$ eine Gruppe genannt, wenn folgendes gilt:
a) Es gilt $(a\circ b)\circ c = a\circ(b\circ c)\forall a,b,c\in G\rightarrow$Assoziativgesetz
b) Es gibt ein neutrales Element $n\in G$, das $n\circ a = a\circ n = a \forall a\in G$ erfüllt.
c) Zu jedem $a\in G$ gibt es ein inverses Element $i(a)\in G$, das$a\circ i(a) = i(a)\circ a = n$ erfüllt

gilt zusätzlich:
d) $a\circ b = b\circ a\forall a,b\in G$ (Kommutativgesetzt), so spricht man von einer Kommutativen oder abelschen Gruppe
####2.6.2 Beispiel
$(\mathbb Z, +)$ also die ganzen mit der Addition bilden eine kommutative Gruppe.
*Beweis:*
(a) Es sei $a,b,c\in\mathbb Z$
$(a+b)+c=a+(b+c)$ Assoziativgesetzt
(b) Es existiert ein neutrales Element in $\mathbb Z$
$n=0\in\mathbb Z$ und es gilt $0+a= a+0 = a\forall a\in\mathbb Z$
(c) Es sei $a\in Z$ mit $i(a)=-a\in\mathbb Z$ gilt
 $a+i(a)=i(a)+a=a+(-a)=(-a)+a=n=0$
(d) Es seien $a,b\mathbb Z$ : 
$a+b = b+a \Rightarrow (\mathbb Z, +)$ ist eine abelsche Gruppe
####2.6.3 Beispiel
$(\mathbb N_0, +)$ ist keine Gruppe, da es kein additives inverses gibt
####2.6.4 Beispiel
$\{\mathbb Q\setminus \{0\}, *\}$
- Assoziativgesetz: $(a*b)*c = a*(b*c)\forall a,b,c\in\mathbb Q\setminus \{0\}$
- neutrales Element: $\frac{1}{a}\in\mathbb Q$, denn $a*1=1*a=a,\forall a\mathbb Q\setminus \{0\}$
- inverses Element$\frac{1}{a}\in\mathbb Q$, denn $a\frac{1}{a}=\frac{1}{a}a=1,\forall a\mathbb Q\setminus \{0\}$
- Kommutativgesetzt: $a*b=b*a\forall a,b\in\mathbb Q$
####2.6.5 Beipiel
$(\mathbb N,*)$ keine Gruppe, da kein inverses Element existiert
####2.6.6 Beispiel
$(\mathbb Z\setminus\{0\},*)$ keine Gruppe$\rightarrow$ inverses Element fehlt
####2.6.7 efinition
Eine Menge $\mathbb K$ mit zweit Verknüpfungen $+$ und $*$, geschrieben $(\mathbb K, +, *)$, heißt Körüer, wenn folgendes gilt
a) $(\mathbb k, +)$ kommutative Gruppe mit neutralem Element $0$
b) $(\mathbb K\setminus\{0\}, *)$ kommutative Gruppe mit neutralem Element 1
c)  Für alle $a,b,c\in\mathbb K$ gilt $a*b+a*c=a*(b+c)$
Distributivgesetzt $\rightarrow$ regelt das Verhalten der beiden Verknüpfungen miteinander
####2.6.8 Beipiel
$\mathbb{Q,R,C}$ sind Körper
####2.6.9 Beispiel
Die Menge $\mathbb F - \{0,1,a,b\}$ bildet mit folgenden Verknüpfungen einen Körper
|+|0|1|a|b
|:-:|:-:|:-:|:-:|:-:|
|0|0|1|a|b
|1|1|0|b|a
|a|a|b|0|1
|b|b|a|1|0

|*|0|1|a|b
|:-:|:-:|:-:|:-:|:-:|
|0|0|0|0|0
|1|0|1|a|b
|a|0|a|b|1
|b|0|b|1|a

##3. Vektoren
###3.1
####3.1.1
Sei $\mathbb K$ ein beliebiger Köörper und V eine Menge mit zwei Verknüfungen:
1. Vektoraddition: Je zwei Elementen $a,b\in V$ wird ein Element $a+b\in V$ zugeordnet, so dass $(V,+)$ eine kommutative Gruppe wird [...]
2. Multiplikation mit einem Skalar: Je einem $a\in V$ und einem $\lambda a\in V$ zugeordnet, sodass $$\lambda(a)=(\lambda\mu)a$$$$1a=a$$$$\lambda(a+b)=\lambda a+\lambda b$$$$(\lambda+\mu)a=\lambda a+\mu a$$ für alle $a,b\in V und \lambda.\mu\in\mathbb K$
Dann wird $V$ ein Vektorraum über den Körper $\mathbb K$. Die Elemente von $V$ werden als Vektoren und die Elemente von $\mathbb K$ als Skalare bezeichnet. Ist $\mathbb K=\mathbb R$, so spricht man von einem reelen Vektorraum und ist $\mathbb K=\mathbb C$ spricht man von einem komplexen Vektorraum.

####3.1.2 Beispiel
Es sei $V=\{\begin{pmatrix} a_1 \\a_2 \\\vdots \\d_1 \end{pmatrix},a;\in\mathbb K, i=1, \dots, n\} = \mathbb K$
 1. DIe Summe zweier Vektoren $$a=\begin{pmatrix} a_1 \\a_2 \\\vdots \\a_n \end{pmatrix},b=\begin{pmatrix} b_1 \\b_2 \\\vdots \\b_n \end{pmatrix}$$ ist der Vektor $$a+b=\begin{pmatrix} a_1+b_1 \\a_2 +b_2\\\vdots \\a_n +b_n\end{pmatrix}$$ Es wird also Koordinatenweise addiert.
 2. Die Multiplikation eines Vektors mit einem Skalar. <br>Es sei $a\in\mathbb K^n $ mit $\begin{pmatrix} a_1 \\a_2\\\vdots \\a_n \end{pmatrix}$  und $\lambda\in\mathbb K$ ist der Vektor $\lambda*a=\begin{pmatrix} \lambda*a_1 \\\lambda*a_2\\\vdots \\\lambda*a_n\end{pmatrix}$ also jede Koordinate mit $\lambda$ multipliziert. <br> $\Rightarrow$ also ist $V$ ein Vektorraum 
$V=\mathbb R^2=\{{a_1 \choose a_2}$mit$a_i\in\mathbb R; i=1,2\}$
$a={1 \choose 2}, b={1 \choose 0}, a={3 \choose 4}$
Berechnen Sie <br>$2a+2(b-c)=2*{1 \choose 2}+2[{1 \choose 0}-{3 \choose 4}]={2 \choose 4}+2[{-2 \choose -4}]={-2 \choose -4}$
####3.1.3 Beispiel
Die <u>Menge aller Polynome</u> vom Grad $\le 2$ kann als Vektorraum aufgefasst werden. Die Summe zweier Polynome $P_1(x)=k_1+k_2*x+k_3*x^2$ und $P_2(x)=h_1+h_2x+h_3x^2$
$P_1(x)+P_2(x) = (k_1+h_1)+(k_2+h_2)x+(k_3+h_3)x^2$ und das Produkt
$\lambda * P_1(x) = \lambda k_1+\lambda k_2 x + \lambda k_3 x^2$ sind wieder Polynome vom Grad $\le 2$. Beide Operatoren erfüllen die Eigenschaften aus der Definition des Vektorraumes.
####3.1.4 Beispiel
Der Raum der affinen Funktion auf den reellen Zahlen 
$f:\mathbb R\rightarrow\mathbb R x\mapsto ax+b\ a,b\in\mathbb R$
bilden einen Vektorraum.
Beispielsweise $f(x)=2x+3\ g(x)=3x-5$
die Summe $f(x)+g(x)=5x-2$, das Produkt $3*f(x)=3(2x+3)=6x+9$
sind wieder affine Funktionen.
Der Nullvektor ist die Gerade $f(x)=0x+0=0$
####3.1.5 Beispiel
Es sei $V=\Omega$ die Menge der Zahlenfolge mit reellen Elementen
$V=\{(x_n)_{n\in\mathbb N}\}$ mit $(x_n)+(y_n)=(x_n+y_n)\\ \alpha(x_n)=(\alpha x_n)$
$V$ ist ein Vektorraum.
####3.1.6 Beispiel
Die leere Menge $\emptyset$ ist kein Vektorraum, da das neutrale Element fehlt
####3.1.7 Beispiel
Es sei eine Menge mit einen Element, das mit 0 bezeichnet wird.
Mit $0+0=0\\ \lambda*0=0 \lambda\in\mathbb K$
ist die Menge ein Vektorrraum.
####3.1.8 Definition
Eine nichtleere Teilmenge $U\subseteq V$ eines Vektorraumes $V$, die selbst ein Vektorraum im Sinne der Definition eines Vektorraumes ist, heißt Teilraum (oder Untervektorraum) von $V$.
####3.1.9 Satz - Kriterien für ein Teilraum
$U\subseteq V$ ist genau dann ein Teilraum des Vektorraumes $V$, wenn $U$ abgeschlossen unter Vektoraddition und Multiplikation mit einem Skalar ist, dh. wenn $\forall a,b\in U$ und $\forall\lambda\in\mathbb K$ gilt $U\neq\emptyset\\ a,b\in U\Rightarrow a+b\in U\\ a\in U\Rightarrow\lambda a\in U$
####3.1.10 Beispiel
Handelt es sich um einen Teilraum des $\mathbb R^2$.
(a)
 $U=\{ {x \choose x} | x\in\mathbb R\} $
   1.  $U\neq\emptyset$, da ${1 \choose 1}\in U$
   2. Es seien $a,b\in U$. $a\in U\Rightarrow={ a_1 \choose a_2 } a_1\in\mathbb R\\ b\in U\Rightarrow={ b_1 \choose b_2 } b_1\in\mathbb R$
   $a+b={a_1 \choose a_2} + {b_1 \choose b_2} = {a_1+ b_1 \choose a_2 + b_2}\in U$
   3. Es seien $\lambda\in\mathbb R$ und $a\in R=a={a_1 \choose a_2} a_1\in\mathbb R$
   $\lambda a = {\lambda a_1\choose \lambda a_2}\in U$
   $\Rightarrow U$ ist ein Untervektorraum.
   (b)
   $U=\{{x \choose y}|x,y\in\mathbb R\ x\ge 0\}$
   1. $U\ne \emptyset$, da ${1 \choose 2}\in U$
   2. Zu zeigen: $ab,b\in U\Rightarrow a+b\in U$
    Es seien $a,b\in U a\in U\Rightarrow a={a_1 \choose a_2} a_1, a_2 \in\mathbb R$
    $a_1\ge 0$
    $b\in U\Rightarrow b={b_1 \choose b_1} b_1,b_2\in\mathbb R\\ b_1\ge 0$
    $a+b = {a_1+b_1 \choose a_2 + b_2}\in U$, da $a_1+b_1\ge 0$
    3. Zz. $\lambda\in\mathbb R$ und $a\in U\Rightarrow\lambda a\in U$
     Es sei $\lambda\in\mathbb R, a\in U\Rightarrow a={a_1 \choose a_2}$
     $\lambda a = {\lambda a_1 \choose \lambda a_2}\notin U$ für $\lambda \lt 0$
     $\Rightarrow$ Kein Unterraum von $R^2$
**Bemerkung**
Insbesondere folgt daraus, dass ein Teilraum U den Nullvektor enthalten muss. Man kann auch zeigen, dass der Durchschnitt zweier Teilräume wieder ein Teilraum ist, die Vereinigung aber nicht.

### 3.2 Lineare Unabhängigkeit und Basis
#### 3.2.1 Definition
Ein Ausdruck der Form 
$$\sum_{j=1}^m \lambda_ia_j = \lambda_1a_1+\dots+\lambda_ma_m$$
mit beliebigen Skalaren $\lambda_1, \lambda_2,...\lambda_m\in\mathbb R$ nennt man eine Linearkombination der Vektoren $a_1, a_2, ... ,a_m\in V$
####3.2.2 Beispiel
Gegeben sind die Vektoren $a_1 = {1 \choose 2}$ und $a_2 = { -2 \choose 2}$. Lässt sich der Vektor $b={1 \choose 5}$ als Linearkombination von $a_1$ und $a_2$ schreiben?
\begin{pmatrix} a_1 \\a_2 \\\vdots \\d_1  \end{pmatrix}
